TextFieldOpenNode class

textField

Constructors

TextFieldOpenNode({required NodeID id, NodeID? parentID, CNode? child, List<CNode>? children, String? name, String? description, double? childOrder, Map<String, dynamic>? attributes, RectProperties? rectProperties, DateTime? updatedAt, PageID? pageID, NodeID? stabilID, PageID? componentID, List<CNode>? componentChildren, bool? isLocked})

Properties

adapter → WidgetAdapter
finalinherited
child → CNode?
The child of the node, if it exists
finalinherited
childNotifier ValueNotifier<CNode?>
finalinherited
childOrder double
The index of the node in the parent's children list
finalinherited
children List<CNode>?
The children of the node, if they exists
finalinherited
childrenNotifier ValueNotifier<Nodes?>
finalinherited
componentChildren List<CNode>
finalinherited
componentID → PageID?
The component id of the node
finalinherited
constraintsEnabled bool
no setterinherited
description → PageID?
The description of the node
finalinherited
flipChild bool
no setterinherited
flipRectWhileResizing bool
no setterinherited
getAttributes Map<String, dynamic>
It returns the node's attributes It merges the default attributes with the current attributes
no setterinherited
getRectProperties → RectProperties
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hideHandlesWhenNotResizable bool
no setterinherited
horizontalAlignment → ResponsiveAlignment
no setterinherited
id → NodeID
The id of the node (node-id)
finalinherited
intrinsicState → IntrinsicState
Intrinsic States of the node
finalinherited
isLocked bool
If the node is locked or not
finalinherited
movable bool
no setterinherited
name → PageID?
The name of each node
finalinherited
pageID → PageID?
The page id of the node
finalinherited
parentID → PageID?
The parent's id of the node
finalinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
rectToJson Map<String, dynamic>
Rect from Json
no setterinherited
resizable bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stabilID → PageID?
Stabil id of the node
finalinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
type → NodeID
Type of the node
finalinherited
updatedAt DateTime
finalinherited
verticalAlignment → ResponsiveAlignment
no setterinherited

Methods

addChildrenToComponent(PageID componentID, List<CNode> children) → CNode
inherited
copyWith({NodeID? id, NodeID? parentID, CNode? child, List<CNode>? children, String? name, String? description, double? childOrder, Map<String, dynamic>? attributes, RectProperties? rectProperties, DateTime? updatedAt, PageID? pageID, NodeID? stabilID, PageID? componentID, List<CNode>? componentChildren, bool? isLocked}) → CNode
Copy the node with new attributes
copyWithOutChild({NodeID? id, NodeID? parentID, CNode? child, List<CNode>? children, String? name, String? description, double? childOrder, Map<String, dynamic>? attributes, RectProperties? rectProperties, DateTime? updatedAt, PageID? pageID, NodeID? stabilID, PageID? componentID, List<CNode>? componentChildren, bool? isLocked}) → CNode
Copy the node with new attributes
doesRectExist(DeviceType deviceType) bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rect(DeviceType deviceType) Rect
inherited
rectPropertiesFromJson(Map<String, dynamic> json) → RectProperties
inherited
rectPropertiesToJson() Map<String, dynamic>
inherited
resetRect(DeviceType deviceType) → RectProperties
inherited
setAttribute(String key, dynamic value) → void
inherited
setConstraintsEnabled(bool value) → void
inherited
setFlipChild(bool value) → void
inherited
setFlipRectWhileResizing(bool value) → RectProperties
inherited
setHideHandlesWhenNotResizable(bool value) → void
inherited
setHorizontalAlignment(ResponsiveAlignment value) → CNode
inherited
setMovable(bool value) → void
inherited
setRect(Rect rect, DeviceType deviceType) → RectProperties
inherited
setRectForMultipleDevices(Map<DeviceType, Rect> rectMap) → RectProperties
inherited
setResizable(bool value) → void
inherited
setVerticalAlignment(ResponsiveAlignment value) → CNode
inherited
toJson() Map<String, dynamic>
toJson method
inherited
toJsonWithId() Map<String, dynamic>
toJson method with id
inherited
toJsonWithIdAndPageId() Map<String, dynamic>
toJson method with id and page id
inherited
toJsonWithStabilId() Map<String, dynamic>
inherited
toJsonWithStabilIdAndPageIdAndId() Map<String, dynamic>
inherited
toString() → NodeID
A string representation of this object.
toStringExtended() → NodeID
toWidget({required BuildContext context, required dynamic state}) Widget
Render a Widget from node
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(String widgetType, Map<String, dynamic> json) → dynamic
fromJson method